@@ -75,27 +75,26 @@ set.generator <- function(name=c("congruRand", "WELL", "MersenneTwister", "defau
 	{
 		if (is.null(parameters))
 		{
-			order <- as.character(dots$order)
-			version <- as.character(dots$version)
-			if (is.null(dots$temper))
-				dots$temper <- ""
-			temper <- as.character(dots$temper)
-			if (temper == "temper")
-				temper <- "Temp"
-			parameters <- c(order=order, version=version, temper=temper)
+			if (is.null(dots$order)) dots$order <- ""
+			if (is.null(dots$version)) dots$version <- ""
+			if (dots$order != "" & nchar(dots$version) != 1) {
+				stop("unsupported parameters order=", dots$order, ", version=", dots$version," for WELL")
+			}
+			version.name <- paste(dots$order, dots$version, sep="")
+			order <- substr(version.name, 1, nchar(version.name) - 1)
+			version <- substr(version.name, nchar(version.name), nchar(version.name))
+			parameters <- c(order=order, version=version)
 		}
-		if (identical(names(parameters), c("order", "version")))
-			parameters <- c(parameters, temper="")
-		if (!identical(names(parameters), c("order", "version", "temper")))
+		if (!identical(names(parameters), c("order", "version")))
 		{
 			param.names <- paste(names(parameters),collapse=" ")
-			cat("parameters required for WELL: order, version, temper\n")
+			cat("parameters required for WELL: order, version\n")
 			cat("parameters provided: ", param.names, "\n")
 			stop("parameter list is not correct for WELL")
 		}
 		if (! paste(parameters, collapse="") %in% c("512a", "521a", "521b", "607a", "607b", "800a", "800b", "1024a", "1024b",
-			"19937a", "19937aTemp", "19937b", "21701a", "23209a", "23209b", "44497a", "44497aTemp"))
-			stop("unsupported parameters for WELL")
+			"19937a", "19937b", "19937c", "21701a", "23209a", "23209b", "44497a", "44497b"))
+			stop("unsupported parameters order=", parameters["order"], ", version=", parameters["version"]," for WELL")
 		if (is.null(seed))
 			seed <- floor(2^31 * runif(1))
 		size <- ceiling(as.numeric(parameters["order"])/32)
@@ -174,8 +173,7 @@ put.description <- function(description)
 		RNGkind("user-supplied")
 		.C("putRngWELL",
 			as.integer(parameters["order"]),
-			match(parameters["version"], c("a", "b"), nomatch=0),
-			as.integer(parameters["temper"] == "Temp"),
+			match(parameters["version"], c("a", "b", "c"), nomatch=0),
 			as.integer(state),
 			PACKAGE="rngWELL")
 	} else if (name == "MersenneTwister")
@@ -209,6 +207,7 @@ get.description <- function()
 			seed=outspace,
 			PACKAGE="randtoolbox")
 		parameters <- aux$parameters
+		names(parameters) <- c("mod", "mult", "incr")
 		seed <- aux$seed
 		state <- c(seed=aux$seed)
 		if(parameters[1] == "4294967296" && parameters[2] == "1664525" && parameters[3] == "1013904223")
@@ -229,13 +228,11 @@ get.description <- function()
 		tmp <- .C("getRngWELL",
 			order = integer(1),
 			version = integer(1),
-			temper = integer(1),
 			state = integer(2000),
 			PACKAGE="rngWELL")
 		order <- as.character(tmp$order)
 		version <- letters[tmp$version]
-		temper <- if (tmp$temper == 1) "Temp" else ""
-		parameters <- c(order=order, version=version, temper=temper)
+		parameters <- c(order=order, version=version)
 		size <- ceiling(tmp$order/32)
 		state <- tmp$state[1:size]
 		literature <- "Panneton - L'Ecuyer - Matsumoto"
